@@ -1,5 +1,5 @@
 use frankenstein::Api;
-use frankenstein::ChatIdEnum;
+use frankenstein::ChatId;
 use frankenstein::GetUpdatesParams;
 use frankenstein::SendMessageParams;
 use frankenstein::TelegramApi;
@@ -7,7 +7,7 @@ use frankenstein::TelegramApi;
 static TOKEN: &str = "API_TOKEN";
 
 fn main() {
-    let api = Api::new(TOKEN.to_string());
+    let api = Api::new(TOKEN);
 
     let mut update_params = GetUpdatesParams::new();
     update_params.set_allowed_updates(Some(vec!["message".to_string()]));
@@ -22,14 +22,16 @@ fn main() {
                 for update in response.result {
                     if let Some(message) = update.message() {
                         let mut send_message_params = SendMessageParams::new(
-                            ChatIdEnum::IsizeVariant(message.chat().id()),
+                            ChatId::Integer(message.chat().id()),
                             "hello".to_string(),
                         );
                         send_message_params.set_reply_to_message_id(Some(message.message_id()));
 
-                        let _ = api.send_message(&send_message_params);
+                        if let Err(err) = api.send_message(&send_message_params) {
+                            println!("Failed to send message: {:?}", err);
+                        }
 
-                        update_params.set_offset(Some(update.update_id() + 1))
+                        update_params.set_offset(Some(update.update_id() + 1));
                     }
                 }
             }
